# BomberKillers
This is a teamwork project for Tools of software projects. We are a team with 4 ELTE computer science BSc students.

Project management is done in the Github/Issues, we divide tasks and showing the current process there. For each milestone, the task and process is clear to every teammember.
We put forward questions and communicate about issues with other. Meanwhile, we also welcome any questions or suggestions from the outsider to help us grow.

BomberKillers is a remake game of Bomberman, which is very famous back to early 2000s in Asia. Here what we want to do is to make the games in higher resolution, also support 4 players play it together (offline and local hosts server ”LAN”), which we cannot do back in the days. We will make the game use python also with the pygame library in VS code.

# Instruction:
This program runs on Python 3, which can be easily downloaded from the following link: 
 https://www.python.org/downloads/
Installation of Pygame is also necessary in order to run this program. 

-- Installing Pygame -- 
Tutorial: https://www.pygame.org/wiki/GettingStarted

After pip has been installed, the following commands can be run one at a time in the command line to install and test Pygame: 

 MacOS-
 python3 -m pip install pygame --user
 python3 -m pygame.examples.aliens

 Windows-
 py -m pip install pygame --user
 py -m pygame.examples.aliens
  
## Executing the Program ## 

To run the program, run the main file "rungame.cmd" 

## Game Play ##

Instructions
One Player - Kill the AI monsters! (continuing)
Two Player - Fight off each other! (continuing)

 ONE PLAYER 
 - Arrow keys to move 
 - Space Bar in order to drop balloons 
 - Left Shift to use items  (continuing)

 TWO PLAYER ---- (continuing)
 - Arrow Keys and WASD to move 
 - Left Shift and Right Shift to drop balloons
 - Left control and space bar to use items 
